.. _intro:

.. _WSGI protocol: https://www.python.org/dev/peps/pep-0333/


Preamble & Disclaimer
=====================

Falcon conforms to the standard `WSGI protocol`_ that most Python web applications
have been using since 2003. If you have deployed Python applications like
Django, Flask, or others, you will find yourself quite at home with Falcon and
your standard Apache/mod_wsgi, gunicorn, or other WSGI servers should suffice.

There are many ways to deploy a Python application. The aim of these quickstarts
is to simply get you up and running, not to give you a perfectly tuned or secure
environment. You will almost certainly need to customize these configurations
for any serious production deployment.
